Pretty and comprehensive printing of MUS evaluation results that can be used for working papers.
# S3 method for MUS.evaluation.result
print(x, error.rate, print.misstatements,
print.planning, print.extraction, print.error.as.pct, print.advice,
style, use.pander, ...)A MUS.evaluation.result object that you got by executing the function MUS.evaluation.
Selects type of error rate calculation (i.e., "high", "low", "both" or "auto"). Defaults to "auto".
Boolean. Should misstatements table be printed? Defaults to TRUE.
Boolean. Should planning parameters be printed? Defaults to FALSE.
Boolean. Should extraction parameters be printed? Defaults to FALSE.
Boolean. Should errors as percentage be printed? Defaults to TRUE.
Boolean. Should recommendations be printed? Defaults to TRUE.
Two options: "report" or "default". Report uses an alternative layout. Defaults to "default".
Boolean. Uses pander to generate rmarkdown report. Defaults to FALSE.
Further arguments, currently ignored.
MUS.evaluation for evaluation of the extracted and
audited sample.