Pretty and comprehensive printing of MUS extraction results that can be used for working papers.
# S3 method for MUS.extraction.result
print(x, print.title,
print.planning, style, use.pander, ...)A MUS.evaluation.result object that you got by executing the function MUS.evaluation.
Boolean. Should title be printed? Defaults to TRUE.
Boolean. Should planning parameters be printed? Defaults to FALSE.
Two options: "report" or "default". Report uses an alternative layout. Defaults to "default".
Boolean. Uses pander to generate rmarkdown report. Defaults to FALSE.
Further arguments, currently ignored.
MUS.extraction for extraction of the audit sample.