Pretty and comprehensive printing of MUS planning results that can be used for working papers.
# S3 method for MUS.planning.result
print(x, print.title,
style, use.pander, ...)A MUS.evaluation.result object that you got by executing the function MUS.evaluation.
Boolean. Should title be printed? Defaults to TRUE.
Two options: "report" or "default". Report uses an alternative layout. Defaults to "default".
Boolean. Uses pander to generate rmarkdown report. Defaults to FALSE.
Further arguments, currently ignored.
MUS.planning for planning of the audit sample.